local VOID_STORAGE_MAX = 80

local slots = {
	"HeadSlot",
	"ShoulderSlot",
	"BackSlot",
	"ChestSlot",
	"WristSlot",
	"HandsSlot",
	"WaistSlot",
	"LegsSlot",
	"FeetSlot",
	"MainHandSlot",
	"SecondaryHandSlot",
}

local currentVoidItem

local origClickTransmogrifySlot = ClickTransmogrifySlot

function ClickTransmogrifySlot(slotID)
	local itemID, _, locked = GetVoidItemInfo(currentVoidItem or 0)
	if locked then
		local soundCVar = GetCVar("Sound_EnableSFX")
		SetCVar("Sound_EnableSFX", 0)
		UseVoidItemForTransmogrify(currentVoidItem, slotID)
		SetCVar("Sound_EnableSFX", soundCVar)
		if CanTransmogrifyItemWithItem(itemID, GetInventoryItemID("player", slotID)) then
			ClearCursor()
			currentVoidItem = nil
		end
		return
	end
	local _, _, _, hasPending = GetTransmogrifySlotInfo(slotID)
	origClickTransmogrifySlot(slotID)
	if hasPending and not GetCursorInfo() then
		local soundCVar = GetCVar("Sound_EnableSFX")
		SetCVar("Sound_EnableSFX", 0)
		ClearCursor()
		SetCVar("Sound_EnableSFX", soundCVar)
	end
end

local function openTransmog()
	ItemAlteration_LoadUI()
	TransmogrifyFrame_Show()
end

SlashCmdList["VOIDTRANSMOG"] = openTransmog
SLASH_VOIDTRANSMOG1 = "/transmog"
SLASH_VOIDTRANSMOG2 = "/vt"

local button = CreateFrame("Button", "BankTransmogrifyButton", BankFrame, "UIPanelButtonTemplate")
button:SetWidth(100)
button:SetPoint("RIGHT", BankItemSearchBox, "LEFT", -16, 0)
button:SetText("Transmogrify")
button:SetScript("OnClick", openTransmog)

local isAtTransmogrifier

button:RegisterEvent("ADDON_LOADED")
button:SetScript("OnEvent", function(self, event, addon)
	if event == "TRANSMOGRIFY_OPEN" then
		isAtTransmogrifier = true
		TransmogrifyFrame_UpdateApplyButton()
	elseif event == "TRANSMOGRIFY_CLOSE" then
		isAtTransmogrifier = false
	else
		if addon == "Blizzard_ItemAlterationUI" then
			-- apparently pending items are retained between sessions, so clear them on load
			local soundCVar = GetCVar("Sound_EnableSFX")
			SetCVar("Sound_EnableSFX", 0)
			for i, slot in ipairs(slots) do
				ClearTransmogrifySlot(GetInventorySlotInfo(slot))
			end
			SetCVar("Sound_EnableSFX", soundCVar)
			
			UIPanelWindows["TransmogrifyFrame"].pushable = 1
			hooksecurefunc("TransmogrifyFrame_UpdateApplyButton", function()
				if not isAtTransmogrifier then
					TransmogrifyApplyButton:Disable()
				end
			end)
			TransmogrifyApplyButton:SetScript("OnEnter", function(self)
				if not isAtTransmogrifier then
					GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
					GameTooltip:AddLine("Visit transmogrifier to apply changes.")
					GameTooltip:Show()
				end
			end)
			TransmogrifyApplyButton:SetScript("OnLeave", GameTooltip_Hide)
			TransmogrifyApplyButton:SetMotionScriptsWhileDisabled(true)
			self:RegisterEvent("TRANSMOGRIFY_OPEN")
			self:RegisterEvent("TRANSMOGRIFY_CLOSE")
		elseif addon == "Blizzard_VoidStorageUI" then
			local function onClick(self)
				currentVoidItem = self.slot
			end
			
			for i = 1, VOID_STORAGE_MAX do
				_G["VoidStorageStorageButton"..i]:HookScript("OnClick", onClick)
				hooksecurefunc("VoidStorageItemButton_OnClick", onClick)
			end
			
			local button = CreateFrame("Button", "VoidTransmogrifyButton", VoidStorageFrame, "UIPanelButtonTemplate")
			button:SetWidth(100)
			button:SetPoint("RIGHT", VoidItemSearchBox, "LEFT", -16, 0)
			button:SetText("Transmogrify")
			button:SetScript("OnClick", openTransmog)
		end
		if IsAddOnLoaded("Blizzard_ItemAlterationUI") and IsAddOnLoaded("Blizzard_VoidStorageUI") then
			self:UnregisterEvent(event)
		end
	end
end)